@@ -3,12 +3,12 @@ package Thread::Serialize;
 # Make sure we have version info for this module
 # Make sure we do everything by the book from now on
 
-our $VERSION = '0.04';
+$VERSION = '0.05';
 use strict;
 
 # Make sure we only load things that we need when we need it
 
-use AutoLoader 'AUTOLOAD';
+use load;
 
 # Make sure we can freeze and thaw
 
@@ -26,7 +26,7 @@ undef( $handle );
 
 1;
 
-# AutoLoader takes over from here
+# The following subroutines are loaded on demand only
 
 __END__
 
@@ -106,6 +106,8 @@ sub import {
 
 #---------------------------------------------------------------------------
 
+__END__
+
 =head1 NAME
 
 Thread::Serialize - serialize data-structures between threads
